==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/StackedColumnSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { HorizontalStackedSeriesBaseDescription } from "./HorizontalStackedSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var StackedColumnSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StackedColumnSeriesDescription, _super);
    function StackedColumnSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.ef = 0;
        _this.eg = 0;
        return _this;
    }
    StackedColumnSeriesDescription.prototype.get_type = function () {
        return "StackedColumnSeries";
    };
    Object.defineProperty(StackedColumnSeriesDescription.prototype, "radiusX", {
        get: function () {
            return this.ef;
        },
        set: function (a) {
            this.ef = a;
            this.e("RadiusX");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(StackedColumnSeriesDescription.prototype, "radiusY", {
        get: function () {
            return this.eg;
        },
        set: function (a) {
            this.eg = a;
            this.e("RadiusY");
        },
        enumerable: true,
        configurable: true
    });
    StackedColumnSeriesDescription.$t = markType(StackedColumnSeriesDescription, 'StackedColumnSeriesDescription', HorizontalStackedSeriesBaseDescription.$);
    return StackedColumnSeriesDescription;
}(HorizontalStackedSeriesBaseDescription));
export { StackedColumnSeriesDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/StackedColumnSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { HorizontalStackedSeriesBaseDescription } from "./HorizontalStackedSeriesBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var StackedColumnSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StackedColumnSeriesDescription, _super);
    function StackedColumnSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.gj = 0;
        _this.gk = 0;
        return _this;
    }
    StackedColumnSeriesDescription.prototype.get_type = function () {
        return "StackedColumnSeries";
    };
    Object.defineProperty(StackedColumnSeriesDescription.prototype, "radiusX", {
        get: function () {
            return this.gj;
        },
        set: function (a) {
            this.gj = a;
            this.g("RadiusX");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(StackedColumnSeriesDescription.prototype, "radiusY", {
        get: function () {
            return this.gk;
        },
        set: function (a) {
            this.gk = a;
            this.g("RadiusY");
        },
        enumerable: false,
        configurable: true
    });
    StackedColumnSeriesDescription.$t = markType(StackedColumnSeriesDescription, 'StackedColumnSeriesDescription', HorizontalStackedSeriesBaseDescription.$);
    return StackedColumnSeriesDescription;
}(HorizontalStackedSeriesBaseDescription));
export { StackedColumnSeriesDescription };
